==> share_apps-0.1.1.tar.gz: lib/screens/invite_contact_screen.dart <==
import 'dart:convert';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:share_apps/screens/contact_selection.dart';
import 'package:share_apps/utils/common_utils.dart';
import 'package:share_apps/utils/string_utils.dart';
import 'package:share_apps/widgets/widgets_importer.dart';

import 'invitaion_complete_screen.dart';

int _transfeID, _transactionId = 1, numOfContactPerApi = 20;
List<dynamic> contactList, contactListForApiCall = new List();

class InviteContact extends StatefulWidget {
  InviteContact(List<CustomContact> uiCustomContacts) {
    contactList = uiCustomContacts;
  }

  @override
  _InviteContactState createState() => _InviteContactState();
}

class _InviteContactState extends State<InviteContact> {
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    BeginTransfer();
  }

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: MaterialApp(
        debugShowCheckedModeBanner: false,
        color: Colors.white,
        home: Scaffold(
          body: Container(
            color: Colors.white,
            child: Column(
              children: [
                Expanded(
                  flex: 1,
                  child: Align(
                    alignment: Alignment.bottomCenter,
                    child: InkWell(
                      onTap: () async {},
                      child: Image.asset(
                        StringUtils.IC_LOGO,
                        width: 50,
                        height: 50,
                      ),
                    ),
                  ),
                ),
                AddSizeBox(100, 0),
                Expanded(
                  flex: 1,
                  child: Container(
                    child: Text(
                      StringUtils.INVITE_CONTACT_MESSAGE,
                      textAlign: TextAlign.center,
                      style: TextStyle(
                          decoration: TextDecoration.none,
                          fontSize: 15,
                          color: Colors.black),
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }

  Future<void> BeginTransfer() async {
    var body = json.encode({
      StringUtils.TOKEN: StringUtils.getToken(),
    });
    Map<String, dynamic> map =
        await CommonUtils.apiCall(StringUtils.BEGIN_TRANSFER, body,context);
    if (map[StringUtils.STATUS].toString().compareTo(StringUtils.SUCCESS) !=
        null) {
      _transfeID = map[StringUtils.TRANSFER_ID];
      InviteContact();
    }
    // CommonUtils.showToast(map[StringUtils.MESSAGE], Colors.green);
  }

  Future<void> InviteContact() async {
    contactListForApiCall = contactList
        .getRange(
            numOfContactPerApi * (_transactionId - 1),
            contactList.length > (numOfContactPerApi * _transactionId)
                ? (numOfContactPerApi * _transactionId)
                : contactList.length)
        .toList();

    var body = json.encode({
      StringUtils.TOKEN: StringUtils.getToken(),
      StringUtils.TRANSFER_ID: _transfeID,
      StringUtils.TRANSACTION_ID: _transactionId,
      StringUtils.CONTACTS: [
        for (int i = 0; i < contactListForApiCall.length; i++)
          ContactData(
                  contactList[i].contact.displayName,
                  contactList[i].contact.emails.toList().length > 0
                      ? [0].toString()
                      : '',
                  contactList[i].contact.phones.toList().length > 0
                      ? [0].toString()
                      : '')
              .toJson(),
      ],
    });

    Map<String, dynamic> map =
        await CommonUtils.apiCall(StringUtils.INVITE_CONTACT, body,context);
    if (map[StringUtils.STATUS].toString().compareTo(StringUtils.SUCCESS) !=
        null) {
      EndTransfer();
    }
  }

  Future<void> EndTransfer() async {
    var body = json.encode({
      StringUtils.TOKEN: StringUtils.getToken(),
    });
    Map<String, dynamic> map =
        await CommonUtils.apiCall(StringUtils.END_TRANSFER, body,context);
    if (map[StringUtils.STATUS].toString().compareTo(StringUtils.SUCCESS) !=
        null) {
      _transactionId = _transactionId + 1;
      if (_transactionId <= (contactList.length / numOfContactPerApi).ceil())
        BeginTransfer();
      else {
        CommonUtils.showToast(map[StringUtils.MESSAGE], Colors.green);
        Route route =
            MaterialPageRoute(builder: (context) => InvitationComplete());
        Navigator.pushReplacement(context, route);
      }
    }
  }
}

class ContactData {
  String name = '', email = '', phone = '';

  ContactData(this.name, this.email, this.phone);

  Map toJson() => {
        'name': name,
        'email': email,
        'phone': phone,
      };
}

==> share_apps-0.1.10.tar.gz: lib/screens/invite_contact_screen.dart <==
import 'dart:convert';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:share_apps/screens/contact_selection.dart';
import 'package:share_apps/utils/common_utils.dart';
import 'package:share_apps/utils/string_utils.dart';
import 'package:share_apps/widgets/widgets_importer.dart';

import 'invitaion_complete_screen.dart';

int _transfeID;
int _transactionId;
int numOfContactPerApi;
List<dynamic> contactList, contactListForApiCall = new List();

class InviteContact extends StatefulWidget {
  InviteContact(List<CustomContact> uiCustomContacts) {
    contactList = uiCustomContacts;
  }

  @override
  _InviteContactState createState() => _InviteContactState();
}

class _InviteContactState extends State<InviteContact> {
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    _transactionId = 1;
    numOfContactPerApi = 20;
    BeginTransfer();
  }

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: MaterialApp(
        debugShowCheckedModeBanner: false,
        color: Colors.white,
        home: Scaffold(
          body: Container(
            color: Colors.white,
            child: Column(
              children: [
                Expanded(
                  flex: 1,
                  child: Align(
                    alignment: Alignment.bottomCenter,
                    child: InkWell(
                      onTap: () async {},
                      child: Image.asset(
                        StringUtils.IC_LOGO,
                        width: 50,
                        height: 50,
                      ),
                    ),
                  ),
                ),
                AddSizeBox(100, 0),
                Expanded(
                  flex: 1,
                  child: Container(
                    child: Text(
                      StringUtils.INVITE_CONTACT_MESSAGE,
                      textAlign: TextAlign.center,
                      style: TextStyle(
                          decoration: TextDecoration.none,
                          fontSize: 15,
                          color: Colors.black),
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }

  Future<void> BeginTransfer() async {
    var body = json.encode({
      StringUtils.TOKEN: StringUtils.getToken(),
    });
    Map<String, dynamic> map =
        await CommonUtils.apiCall(StringUtils.BEGIN_TRANSFER, body, context);
    if (map[StringUtils.STATUS].toString().compareTo(StringUtils.SUCCESS) !=
        null) {
      _transfeID = map[StringUtils.TRANSFER_ID];
      InviteContact();
    }
    // CommonUtils.showToast(map[StringUtils.MESSAGE], Colors.green);
  }

  Future<void> InviteContact() async {
    contactListForApiCall = contactList
        .getRange(
            numOfContactPerApi * (_transactionId - 1),
            contactList.length > (numOfContactPerApi * _transactionId)
                ? (numOfContactPerApi * _transactionId)
                : contactList.length)
        .toList();

    var body = json.encode({
      StringUtils.TOKEN: StringUtils.getToken(),
      StringUtils.TRANSFER_ID: _transfeID,
      StringUtils.TRANSACTION_ID: _transactionId,
      StringUtils.CONTACTS: [
        for (int i = 0; i < contactListForApiCall.length; i++)
          ContactData(
                  contactList[i].contact.displayName,
                  contactList[i].contact.emails.toList().length > 0
                      ? [0].toString()
                      : '',
                  contactList[i].contact.phones.toList().length > 0
                      ? [0].toString()
                      : '')
              .toJson(),
      ],
    });

    Map<String, dynamic> map =
        await CommonUtils.apiCall(StringUtils.INVITE_CONTACT, body, context);
    if (map[StringUtils.STATUS].toString().compareTo(StringUtils.SUCCESS) !=
        null) {
      EndTransfer();
    }
  }

  Future<void> EndTransfer() async {
    var body = json.encode({
      StringUtils.TOKEN: StringUtils.getToken(),
    });
    Map<String, dynamic> map =
        await CommonUtils.apiCall(StringUtils.END_TRANSFER, body, context);
    if (map[StringUtils.STATUS].toString().compareTo(StringUtils.SUCCESS) !=
        null) {
      _transactionId = _transactionId + 1;
      if (_transactionId <= (contactList.length / numOfContactPerApi).ceil())
        BeginTransfer();
      else {
        CommonUtils.showToast(map[StringUtils.MESSAGE], Colors.green);
        Route route =
            MaterialPageRoute(builder: (context) => InvitationComplete());
        Navigator.pushReplacement(context, route);
      }
    }
  }
}

class ContactData {
  String name = '', email = '', phone = '';

  ContactData(this.name, this.email, this.phone);

  Map toJson() => {
        'name': name,
        'email': email,
        'phone': phone,
      };
}
